==> order-center-domain-2.0.9-CLOUD-TEST-20220417.223057-91-sources.jar: com/tydic/dyc/oc/model/audit/sub/UocApprovalLog.java <==
package com.tydic.dyc.oc.model.audit.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocApprovalLogPo
 * 说明:审批日志表
 * 时间:2022-02-23 20:57
 * 作者:罗有
 **/
@Data
public class UocApprovalLog implements Serializable {
	private static final long serialVersionUID = 8811308502177865542L;

	@DocField(value = "id")
	private Long id;

	@DocField(value = "审核单id")
	private Long auditOrderId;

	@DocField(value = "审批结果：0通过、1未通过")
	private Integer auditResult;

	private String auditAdvice;

	private String operid;

	private String operDept;

	private String stepId;

	private String stepName;

	private String stepDesc;

	private String preOperId;

	private Long orderId;

	private Integer objType;

	private Integer auditConsumerType;

	private Integer objNum;

	private String busiCode;

	private Date createTime;

	@DocField(value = "null 开始")
	private Date createTimeStart;

	@DocField(value = "null 结束")
	private Date createTimeEnd;

	private Date dealTime;

	@DocField(value = "null 开始")
	private Date dealTimeStart;

	@DocField(value = "null 结束")
	private Date dealTimeEnd;

	private String nextStepName;

	private String nextStepDesc;

	private String nextOperId;

	private String nextOperName;

	private Integer finish;

	private String operName;

	private String nextStepId;

	private String preOperName;

	private String nextStationId;

	private String nextStationName;

	@DocField(value = "排序")
	private String orderBy;

}

==> order-center-domain-3.1.0-CLOUD-TEST-20230331.003415-64-sources.jar: com/tydic/dyc/oc/model/audit/sub/UocApprovalLog.java <==
package com.tydic.dyc.oc.model.audit.sub;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocApprovalLogPo
 * 说明:审批日志表
 * 时间:2022-02-23 20:57
 * 作者:罗有
 **/
@Data
public class UocApprovalLog implements Serializable {
	private static final long serialVersionUID = 8811308502177865542L;

	@DocField(value = "id")
	private Long id;

	@DocField(value = "审核单id")
	private Long auditOrderId;

	@DocField(value = "审批结果：0驳回、1通过、2待审批")
	private Integer auditResult;

	private String auditAdvice;

	private String operid;

	private String operDept;

	private String stepId;

	private String stepName;

	private String stepDesc;

	private String preOperId;

	private Long orderId;

	private Integer objType;

	private Integer auditConsumerType;

	private Integer objNum;

	private String busiCode;

	private Date createTime;

	@DocField(value = "null 开始")
	private Date createTimeStart;

	@DocField(value = "null 结束")
	private Date createTimeEnd;

	private Date dealTime;

	@DocField(value = "null 开始")
	private Date dealTimeStart;

	@DocField(value = "null 结束")
	private Date dealTimeEnd;

	private String nextStepName;

	private String nextStepDesc;

	private String nextOperId;

	private String nextOperName;

	private Integer finish;

	private String operName;

	private String nextStepId;

	private String preOperName;

	private String nextStationId;

	private String nextStationName;

	@DocField(value = "排序")
	private String orderBy;

}
